<?php

namespace Lavalite\Litecm\Policies;

use Litepie\User\Contracts\UserPolicy;
use Lavalite\Litecm\Models\Shopping;

class ShoppingPolicy
{

    /**
     * Determine if the given user can view the shopping.
     *
     * @param UserPolicy $user
     * @param Shopping $shopping
     *
     * @return bool
     */
    public function view(UserPolicy $user, Shopping $shopping)
    {
        if ($user->canDo('litecm.shopping.view') && $user->isAdmin()) {
            return true;
        }

        return $shopping->user_id == user_id() && $shopping->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shopping.
     *
     * @param UserPolicy $user
     * @param Shopping $shopping
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('litecm.shopping.create');
    }

    /**
     * Determine if the given user can update the given shopping.
     *
     * @param UserPolicy $user
     * @param Shopping $shopping
     *
     * @return bool
     */
    public function update(UserPolicy $user, Shopping $shopping)
    {
        if ($user->canDo('litecm.shopping.edit') && $user->isAdmin()) {
            return true;
        }

        return $shopping->user_id == user_id() && $shopping->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shopping.
     *
     * @param UserPolicy $user
     * @param Shopping $shopping
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Shopping $shopping)
    {
        return $shopping->user_id == user_id() && $shopping->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shopping.
     *
     * @param UserPolicy $user
     * @param Shopping $shopping
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Shopping $shopping)
    {
        if ($user->canDo('litecm.shopping.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shopping.
     *
     * @param UserPolicy $user
     * @param Shopping $shopping
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Shopping $shopping)
    {
        if ($user->canDo('litecm.shopping.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
