<?php

namespace Lavalite\Litecm\Providers;

use Illuminate\Support\ServiceProvider;

class LitecmServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'litecm');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'litecm');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('lavalite.litecm', function ($app) {
            return $this->app->make('Lavalite\Litecm\Litecm');
        });

                // Bind Shopping to repository
        $this->app->bind(
            'Lavalite\Litecm\Interfaces\ShoppingRepositoryInterface',
            \Lavalite\Litecm\Repositories\Eloquent\ShoppingRepository::class
        );

        $this->app->register(\Lavalite\Litecm\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Lavalite\Litecm\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lavalite.litecm'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lavalite/litecm.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/litecm')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/litecm')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
